@@ -1,12 +1,10 @@
 """Numeral System Counters, by Al Sweigart al@inventwithpython.com
-
-Shows the equivalent numbers in decimal, hexadecimal, and binary.
-Tags: short, math"""
+Shows equivalent numbers in decimal, hexadecimal, and binary.
+This and other games are available at https://nostarch.com/XX
+Tags: tiny, math"""
 
 __version__ = 0
-
-print('''Numeral System Counters
-By Al Sweigart al@inventwithpython.com
+print('''Numeral System Counters, by Al Sweigart al@inventwithpython.com
 
 This program shows you equivalent numbers in decimal (base 10),
 hexadecimal (base 16), and binary (base 2) numeral systems.
@@ -15,7 +13,7 @@ hexadecimal (base 16), and binary (base 2) numeral systems.
 ''')
 
 while True:
-    response = input('Enter the starting number> ')
+    response = input('Enter the starting number (e.g. 0) > ')
     if response == '':
         response = '0'  # Start at 0 by default.
         break
@@ -25,7 +23,7 @@ while True:
 start = int(response)
 
 while True:
-    response = input('Enter how many numbers to display> ')
+    response = input('Enter how many numbers to display (e.g. 1000) > ')
     if response == '':
         response = '1000'  # Display 1000 numbers by default.
         break
