@@ -1,29 +1,24 @@
 """Guess the Number, by Al Sweigart al@inventwithpython.com
-
-While given hints, try to guess the secret number.
-Tags: tiny, game"""
+Try to guess the secret number based on hints.
+This and other games are available at https://nostarch.com/XX
+Tags: tiny, beginner, game"""
 __version__ = 0
-
-# A version of this game is featured in the book, "Invent Your Own
-# Computer Games with Python. https://nostarch.com/inventwithpython
-
 import random
 
-print('''GUESS THE NUMBER
-By Al Sweigart al@inventwithpython.com
-''')
-
+print('Guess the Number, by Al Sweigart al@inventwithpython.com')
+print()
 secretNumber = random.randint(1, 100)  # Select a random number.
 print('I am thinking of a number between 1 and 100.')
 
 for i in range(10):  # Give the player 10 guesses.
-    print('You have ' + str(10 - i) + ' guesses left. Take a guess.')
+    print('You have {} guesses left. Take a guess.'.format(10 - i))
     while True:
-        try:
-            guess = int(input())  # Enter the guess.
-            break  # Break out of the while loop.
-        except:
-            print('Please enter a number.')
+        guess = input('> ')  # Enter the guess.
+
+        if guess.isdecimal():
+            guess = int(guess)  # Convert string guess to an integer.
+            break  # Break out of this while loop.
+        print('Please enter a number.')
 
     if guess == secretNumber:
         break  # Break out of the for loop if the guess is correct.
