@@ -1,10 +1,13 @@
 """Zigzag, by Al Sweigart al@inventwithpython.com
-
 A simple zig zag animation. Press Ctrl-C to stop.
-Tags: tiny, artistic, scrolling"""
+This and other games are available at https://nostarch.com/XX
+Tags: tiny, beginner, artistic, scrolling"""
 __version__ = 0
+import sys, time
 
-import time, sys
+print('Zigzag, by Al Sweigart al@inventwithpython.com')
+print('Press Ctrl-C to quit.')
+time.sleep(3)
 
 indentSize = 0  # How many spaces to indent.
 
@@ -23,6 +26,5 @@ try:
             indentation = ' ' * indentSize
             print(indentation + '********')
             time.sleep(0.05)  # Pause for 50 milliseconds.
-    # At this point, go back to the start of the main program loop.
 except KeyboardInterrupt:
     sys.exit()  # When Ctrl-C is pressed, end the program.
